function deleteDatalessPedigrees(path)
% deleteOrphanPedigrees(path)
% 
% Removes pedigree files without "child" data files in the class
%
% Attention: Should NOT be called between calling 
%    filename=createPedigree(...)
% and using the returned filename to create the data file.
%
% (This is especially important to keep in mind for files that may be
% manually created much later.)
%
% Copyright (C) 2010-2014  Joao Hespanha

verboseLevel=1;

%% get key formating parameters for filenames
[filename,pedigreeName,pedigreeSuffix,dateFormat,basenameUniqueRegexp,timeStampFormat,pedigreeWildcard]=createPedigree();

%% get list of pedigree files
wildcard=sprintf(pedigreeWildcard,path,'/*',pedigreeSuffix);
pedigrees=dir(wildcard);

for thisPedigree=1:length(pedigrees)
    thisName=[path,'/',pedigrees(thisPedigree).name];
    fprintf('Analysing pedigree: %s\n',pedigrees(thisPedigree).name);

    thisWildcard=regexprep(thisName,[pedigreeSuffix,'$'],'*');

    matchFiles=dir(thisWildcard);
    
    match=false;
    for i=1:length(matchFiles)
        if strcmp(matchFiles(i).name,pedigrees(thisPedigree).name) 
            %            fprintf('   same (ignored)\n');
            continue;
        end
        if verboseLevel>1
            fprintf('         data file: %s\n',matchFiles(i).name)
        end
        match=true;
    end
    
    if ~match
        filename=[path,'/',matchFiles(i).name];
        fprintf('***      NO DATA, will delete %s\n',filename);
        delete(filename);
    end
end

    
    